@@ -32,7 +32,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub _ANYPROCESS                    { return -1 }
 sub _COMMAND                       { return 0 }
@@ -46,6 +46,9 @@ sub new {
     my $self = bless {}, $class;
     my @arguments = ('-marionette');
     $self->{last_message_id} = 0;
+    if (!$parameters{addons}) {
+	push @arguments, '-safe-mode';
+    }
 
     $self->{debug} = $parameters{debug};
     if (   ( defined $parameters{capabilities} )
@@ -1218,7 +1221,7 @@ sub quit {
         while ( kill 0, $pid ) {
             kill $signal, $pid;
             sleep 1;
-            waitpid $pid, POSIX::WNOHANG();
+            waitpid _ANYPROCESS(), POSIX::WNOHANG();
         }
         delete $self->{_xvfb_display_number};
         delete $self->{_xvfb_authority_directory};
@@ -1566,7 +1569,7 @@ Firefox::Marionette - Automate the Firefox browser with the Marionette protocol
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SYNOPSIS
 
@@ -1599,11 +1602,13 @@ accepts an optional hash as a parameter.  Allowed keys are below;
 
 =item * capabilities - use the supplied L<capabilities|Firefox::Marionette::Capabilities> object, for example to set whether the browser should L<accept insecure certs|Firefox::Marionette::Capabilities#accept_insecure_certs>
 
-=item * profile_name - pick a specific existing profile to automate, rather than creating a new profile.  Note that L<firefox|https://firefox.com> refuses to allow more than one instance of a profile to run at the same time.  Profile names can be obtained by using the L<Firefox::Marionette::Profile::names()|Firefox::Marionette::Profile#names> method.  NOTE: firefox ignores any chagnes made to the profile on the disk while it is running.
+=item * profile_name - pick a specific existing profile to automate, rather than creating a new profile.  Note that L<firefox|https://firefox.com> refuses to allow more than one instance of a profile to run at the same time.  Profile names can be obtained by using the L<Firefox::Marionette::Profile::names()|Firefox::Marionette::Profile#names> method.  NOTE: firefox ignores any changes made to the profile on the disk while it is running.
 
 =item * profile - create a new profile based on the supplied profile.  NOTE: firefox ignores any changes made to the profile on the disk while it is running.
 
-=item * debug - allow firefox's debug to be available via STDERR.
+=item * debug - should firefox's debug to be available via STDERR. This defaults to "0".
+
+=item * addons - should any firefox extensions and themes be available in this session.  This defaults to "0".
 
 =back
 
@@ -1909,13 +1914,25 @@ The module was found that firefox is reporting through it's L<Capabilities|Firef
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-Firefox::Marionette requires no configuration files or environment variables.
+Firefox::Marionette requires no configuration files or environment variables.  It will however use the DISPLAY and XAUTHORITY environment variables to try to connect to an X Server.
 
 
 =head1 DEPENDENCIES
 
-None.
-
+Firefox::Marionette requires the following non-core Perl modules
+ 
+=over
+ 
+=item *
+L<JSON|JSON>
+ 
+=item *
+L<URI|URI>
+ 
+=item *
+L<Crypt::URandom|Crypt::URandom>
+ 
+=back
 
 =head1 INCOMPATIBILITIES
 
