@@ -14,7 +14,7 @@ BEGIN {
         require Win32;
     }
 }
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub _ANY_PORT           { return 0 }
 sub _GETPWUID_DIR_INDEX { return 7 }
@@ -236,7 +236,7 @@ Firefox::Marionette::Profile - Represents a prefs.js Firefox Profile
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SYNOPSIS
 
@@ -311,7 +311,14 @@ Firefox::Marionette::Profile requires no configuration files or environment vari
 
 =head1 DEPENDENCIES
 
-None.
+Firefox::Marionette requires the following non-core Perl modules
+ 
+=over
+ 
+=item *
+L<Config::INI::Reader|Config::INI::Reader>
+ 
+=back
 
 =head1 INCOMPATIBILITIES
 
